MethodChannelSttRecord class
An implementation of SttRecordPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SttRecordPlatform
- MethodChannelSttRecord
Constructors
Properties
- eventChannel → EventChannel
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
transcripts
→ Stream<
Map< Object?, Object?> > -
no setteroverride
Methods
-
cancel(
) → Future< void> -
override
-
getAmplitude(
) → Future< double> -
Returns the current microphone amplitude while recording.
override
-
getLocales(
) → Future< List< Map< >Object?, Object?> > -
Returns supported locale IDs for speech recognition.
override
-
hasPermission(
) → Future< bool> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → Future< void> -
Pauses the current session (recording + recognition) without finalizing.
override
-
requestPermission(
) → Future< bool> -
override
-
resume(
) → Future< void> -
Resumes a previously paused session.
override
-
start(
{required String localeId, required bool partialResults, bool enableSystemNotification = false, String systemNotificationTitle = 'Recording', String systemNotificationBody = 'Recording is running', bool enableSystemNotificationActionPause = false, bool enableSystemNotificationActionStop = false}) → Future< void> -
override
-
stop(
) → Future< Map< Object?, Object?> > -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited